@@ -2,6 +2,7 @@ import datetime
 
 def hello():
     current = datetime.datetime.now()
-    message = 'Hey. It is now ' + str(current)
+    message = 'Hey! It is now ' + str(current)
+    print(message)
     return message
 
